@@ -3,10 +3,11 @@ package-name is utility to create sub process.
 
 """
 
-__version__ = "0.1.6"
-__name__ = "md2zhihu"
+from .version import __version__
+from .version import __name__
 
-from . import mistune
 from . import md2zhihu
+from . import mistune
 from .md2zhihu import main
-
+from .md2zhihu import AssetRepo
+from .md2zhihu import Config
